@@ -1,4 +1,5 @@
 import datetime
+from typing import Union
 
 
 def default(value: object):
@@ -25,6 +26,17 @@ def address(value: dict):
     return ", ".join(values) if values else None
 
 
+def multiple_choice(value: Union[list, str]):
+    """ Handle a single string or list of strings """
+    if isinstance(value, list):
+        # account for this odd [None] value for empty multi-select fields
+        if value == [None]:
+            return None
+        # we use string formatting to handle the possiblity that the list contains ints
+        return ", ".join([f"{val}" for val in value])
+    return value
+
+
 def signature(value: dict):
     return value.get("base30")
 
